Properties Methods Events Direct Link

# Class Ext.ensible.cal.EventEditForm

Package: | Ext.ensible.cal
Defined In: | EventEditForm.js
Class: | EventEditForm
Extends: | Object

A custom form used for detailed editing of events.

This is pretty much a standard form that is simply pre-configured for the options needed by the calendar components. It is also configured to automatically bind records of type Ext.ensible.cal.EventRecord to and from the form.

This form also provides custom events specific to the calendar so that other calendar components can be easily notified when an event has been edited via this component.

The default configs are as follows:

    labelWidth: 65,
    labelWidthRightCol: 65,
    colWidthLeft: .6,
    colWidthRight: .4,
    title: 'Event Form',
    titleTextAdd: 'Add Event',
    titleTextEdit: 'Edit Event',
    titleLabelText: 'Title',
    datesLabelText: 'When',
    reminderLabelText: 'Reminder',
    notesLabelText: 'Notes',
    locationLabelText: 'Location',
    webLinkLabelText: 'Web Link',
    calendarLabelText: 'Calendar',
    repeatsLabelText: 'Repeats',
    saveButtonText: 'Save',
    deleteButtonText: 'Delete',
    cancelButtonText: 'Cancel',
    bodyStyle: 'padding:20px 20px 10px;',
    border: false,
    buttonAlign: 'center',
    autoHeight: true // to allow for the notes field to autogrow

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

Event | Defined By
--- | ---
| eventadd : ( `Ext.ensible.cal.EventEditForm this`, `Ext.ensible.cal.EventRecord rec` ) Fires after a new event is added Fires after a new event is added Listeners will be called with the following arguments: `this` : Ext.ensible.cal.EventEditForm `rec` : Ext.ensible.cal.EventRecord The new record that was added | EventEditForm
| eventcancel : ( `Ext.ensible.cal.EventEditForm this`, `Ext.ensible.cal.EventRecord rec` ) Fires after an event add/edit operation is canceled by the user and no store update took place Fires after an event add/edit operation is canceled by the user and no store update took place Listeners will be called with the following arguments: `this` : Ext.ensible.cal.EventEditForm `rec` : Ext.ensible.cal.EventRecord The new record that was canceled | EventEditForm
| eventdelete : ( `Ext.ensible.cal.EventEditForm this`, `Ext.ensible.cal.EventRecord rec` ) Fires after an event is deleted Fires after an event is deleted Listeners will be called with the following arguments: `this` : Ext.ensible.cal.EventEditForm `rec` : Ext.ensible.cal.EventRecord The new record that was deleted | EventEditForm
| eventupdate : ( `Ext.ensible.cal.EventEditForm this`, `Ext.ensible.cal.EventRecord rec` ) Fires after an existing event is updated Fires after an existing event is updated Listeners will be called with the following arguments: `this` : Ext.ensible.cal.EventEditForm `rec` : Ext.ensible.cal.EventRecord The new record that was updated | EventEditForm